set drp_Version 2.0
# ------------------------------------------------------------------------
#       Name: drpoker.tcl
#      Title: Doctor Po's Draw Poker
#       Date: Sat Aug 16 15:00 2003
#     Author: Greg McNeil <gmcneil@yahoo.com>
#    Purpose: Deals a game of 5 Card Draw Poker to as many as five
#             players. Cards are dealt face up from a regular shuffled
#             deck (plus two wild cards). Players then discard and
#             draw cards. Game ends when bot shows final hands.
#             The game can operate independently on multiple channels.
#      Notes: Designed for Eggdrop 1.6, Tcl 8.4, and Undernet.
# ------------------------------------------------------------------------
#    Doctor Po's Draw Poker, a Tcl script for Eggdrop bots. The bot
#    deals hands of 5 card draw poker to players on IRC channels.
#    Copyright (C) 2003 Greg McNeil
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    If you did not receive a copy of the GNU General Public License
#    along with this program, obtain a copy by writing to the Free
#    Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
# ------------------------------------------------------------------------

# ------------------------------------------------------------------------
#    The Dr. Po Poker Script...

 # --------------------------------
 #  Bindings...
 #
 #    !poker   to get the game started...
 #    !deal    to see who is playing...
 #    !draw    for players to draw/keep cards...
 #    !keep    opposite of draw...
 #    !fold    for players to fold...
 #
bind pub - "!poker" DrP.Poker
bind pub - "!deal"  DrP.Deal
bind pub - "!draw"  DrP.Draw
bind pub - "!keep"  DrP.Keep
bind pub - "!fold"  DrP.Fold
 #
 # --------------------------------

 # --------------------------------
 #  DrP.Poker
 #    This starts the game at the !poker command.
 #
proc DrP.Poker { drp_nick v1 v2 drp_chan drp_text } {
   global drp_Running drp_Dealing drp_Drawing drp_Players drp_OppedOff

    # -- bail out if the bot triggered this proc...
   if { [isbotnick "${drp_nick}"] } { return -code ok }

    # -- parse args to check for "help" or "on/off" command...
   set drp_on 0
   if { ![string equal "" "${drp_text}"] } {
      regsub -all \[^a-z\ \] [lrange [split \
            [string tolower "${drp_text}"] ] 0 1] "" drp_swtch
      switch [lindex ${drp_swtch} 0] {
         "help" {
            DrP.Help "${drp_chan}" [lindex ${drp_swtch} 1]
            return -code ok
         }
         "on" {
            if { [isop "${drp_nick}" "${drp_chan}"] &&
                  [info exists drp_OppedOff(${drp_chan})] } {
               after 1000 [list unset drp_OppedOff(${drp_chan})]
               after 2000
               set drp_on 1
            } {
               return -code ok
            }
         }
         "off" {
            if { [isop "${drp_nick}" "${drp_chan}"] } {
               set drp_OppedOff(${drp_chan}) 1
            }
            return -code ok
         }
         default { return -code ok }
      }
   }

    # -- bail out if Opped Off...
   if { ! ${drp_on} && [info exists drp_OppedOff(${drp_chan})] } {
      if { ![rand 8] } {
         set drp_talk "\[poker is \"off\"..\
               an OP must type \"!poker on\" to restart\]"
         putserv [concat \
               PRIVMSG "${drp_chan}" :\001ACTION * ${drp_talk}\001]
      }
      return -code ok
   }

    # -- bail out if already playing on this channel...
   if { [info exists drp_Running(${drp_chan})] } { return -code ok }

    # -- clear players list and start session...
   after 60000 [list unset drp_Players(${drp_chan})]
   set drp_Players(${drp_chan}) ""
   after 60000 [list unset drp_Running(${drp_chan})]
   set drp_Running(${drp_chan}) 1

    # -- wait 10 more seconds for them to !deal in then play...
   after 10000 [list DrP.Play "${drp_chan}"]
   after 12000 [list unset drp_Dealing(${drp_chan})]
   set drp_Dealing(${drp_chan}) 1

    # -- pick a phrase and send it to the channel...
   set drp_talk {
      "any 5 players for poker?.. type !deal to play.."
      "okay i'm dealing 5 card draw.. !deal gets you in the game.."
      "i'll shuffle the deck.. type !deal to play poker.."
      "type !deal to play poker.. 5 players.. dealing soon.."
      "type !deal to join the poker game.. starts in 8 seconds.."
      "dealing poker in 8 seconds.. type !deal to get in the game.."
      "type !deal to get in the poker game.. up to 5 players.."
      "to play poker type !deal.. game in 10 seconds.. 9.. 8.."
      "playing poker in 8 seconds.. type !deal to get in.."
      "poker game coming up in 8 seconds.. use !deal to play.."
   }
   lappend drp_talk "welcome to Dr. Po Poker.. type !deal to get in.."
   putserv [concat PRIVMSG "${drp_chan}" :\001ACTION * \
         [lindex ${drp_talk} [rand [llength ${drp_talk}]]]\001]

   return -code ok
}
 #
 # --------------------------------

 # --------------------------------
 #  DrP.Deal
 #    This creates the list of players from the !deal command.
 #
proc DrP.Deal { drp_nick drp_uhst v2 drp_chan v4 } {
   global drp_Running drp_Dealing drp_Players

    # -- bail out if the bot triggered this proc...
   if { [isbotnick "${drp_nick}"] } { return -code ok }

    # -- bail out if not playing on this channel...
   if { ![info exists drp_Running(${drp_chan})] } { return -code ok }

    # -- bail out if not currently !deal'ing on this channel...
   if { ![info exists drp_Dealing(${drp_chan})] } { return -code ok }

    # -- bail out if this nick or uhst is already in...
   foreach drp_player $drp_Players(${drp_chan}) {
      if { [string equal "${drp_nick}" [lindex ${drp_player} 0]] ||
             [string equal "${drp_uhst}" [lindex ${drp_player} 1]] } {
         return -code ok
      }
   }

    # -- add nick to players list...
   lappend drp_Players(${drp_chan}) [list "${drp_nick}" "${drp_uhst}"]

    # -- end the dealing and move along if all seats are taken...
   if { [llength $drp_Players(${drp_chan})] >= 5 } { 
      if { [info exists drp_Dealing(${drp_chan})] } {
         unset drp_Dealing(${drp_chan})
      }
      after 1000 [list DrP.Play "${drp_chan}"]
      return -code ok
   }

   return -code ok
}
 #
 # --------------------------------

 # --------------------------------
 #  DrP.Play
 #    This makes a shuffled deck and deals each player a hand.
 #
proc DrP.Play { drp_chan } {
   global botnick drp_Running drp_Dealing drp_Drawing drp_Players

    # -- cancel any upcoming "afters"...
   after cancel [list DrP.Play "${drp_chan}"]

    # -- bail out if not playing on this channel...
   if { ![info exists drp_Running(${drp_chan})] } { return -code ok }

    # -- end dealing... (was set in DrP.Poker to let them !deal)...
   if { [info exists drp_Dealing(${drp_chan})] } {
      unset drp_Dealing(${drp_chan})
   }

    # -- bail out if nobody is in...
   if { ![llength $drp_Players(${drp_chan})] } {
      DrP.NoPlayers "${drp_chan}"
      return -code ok
   }

    # -- build a shuffled deck plus 2 wild cards...
   set drp_deck { "\00303,00 -WILD- \003" "\00306,00 =WILD= \003" }
    # -- uncomment the next line to remove wild cards...
   # set drp_deck ""
   foreach drp_numb { A 4 7 T K 3 6 9 Q 2 5 8 J } {
      foreach drp_suit { "\00304,00 D \003" "\00301,00 C \003" \
            "\00304,00 H \003" "\00301,00 S \003" } {
          # -- make a card and insert in random location in deck...
         set drp_deck [linsert ${drp_deck} \
               [rand [expr [llength ${drp_deck}] + 1]] [join \
               [linsert [split ${drp_suit}] 1 "${drp_numb} of"]]]
          # -- cut the deck at a random location...
         set drp_deck [concat [lrange ${drp_deck} [set drp_cut \
               [rand [expr [llength ${drp_deck}] + 1]]] end] \
               [lrange ${drp_deck} 0 [expr ${drp_cut} - 1]]]
      }
   }

    # -- let the bot play if only one player is in...
   if { [llength $drp_Players(${drp_chan})] == 1 } {
      set drp_Players(${drp_chan}) \
            [linsert $drp_Players(${drp_chan}) 0 \
            [list "${botnick}" "${botnick}"]]
   }

    # -- make the players' hands and the local players list...
   set drp_count 0
   set drp_plist ""
   foreach drp_player [lrange $drp_Players(${drp_chan}) 0 4] {
      set drp_hlen 8
      if { [isbotnick [set drp_thenick [lindex ${drp_player} 0]]] } {
         set drp_hlen 4
      }
      lappend drp_plist "${drp_thenick}"
      set drp_Players(${drp_chan}) [lreplace \
            $drp_Players(${drp_chan}) ${drp_count} \
            ${drp_count} [linsert [lrange ${drp_deck} 0 \
            ${drp_hlen}] 0 "${drp_thenick}"]]
      set drp_deck [lrange ${drp_deck} 9 end]
      incr drp_count
   }

    # -- open drawing phase and wait 20 seconds before DrP.Show...
   after [expr ( [llength ${drp_plist}] * 3000 ) + 20000] \
         [list DrP.Show "${drp_chan}"]
   after [expr ( [llength ${drp_plist}] * 3000 ) + 22000] \
         [list unset drp_Drawing(${drp_chan})]
   set drp_Drawing(${drp_chan}) 1

    # -- announce player names and prepare to deal the cards...
   set drp_talk {
      "ready players?.. 5 cards for"
      "dealing a hand of poker to"
      "a hand of poker for"
      "let's see who got in.."
      "who is playing this time?.."
      "i'm about to deal cards to"
      "dealing a lucky hand to"
      "laying cards in front of"
      "preparing to deal cards to"
      "who's in?.. okay it's"
   }
   set drp_plist [linsert ${drp_plist} end-1 "and"]      
   putserv [concat PRIVMSG "${drp_chan}" \
         :\001ACTION * [lindex ${drp_talk} [rand \
         [llength ${drp_talk}]]] [join ${drp_plist}]..\001]

    # -- deal the cards...
   foreach drp_hand $drp_Players(${drp_chan}) {
      putserv [concat PRIVMSG \
            "${drp_chan}" :\001ACTION \00301,15[format " % 9s " \
            [lindex ${drp_hand} 0]]\003[join [lrange \
            ${drp_hand} 1 5] "\00301,15 \003"]\00301,15 \003\001]
   }

    # -- prepare to discard and draw new cards...
   set drp_talk {
      "discard the bad and keep the good.. draw.."
      "draw your new cards now.. you have 15 seconds.."
      "15 seconds to discard and draw new cards.."
      "all players.. 15 seconds to draw new cards now.."
      "time for the players to draw.. 15 seconds.."
      "you have 15 seconds now to draw new cards.."
      "draw now.. but only 3 cards unless you keep an Ace.."
      "now is your chance.. 15 seconds to draw.."
      "there you go.. time to discard and draw now.."
      "you can draw 4 cards if you keep an Ace.. so draw.."
   }
   putserv [concat PRIVMSG "${drp_chan}" :\001ACTION * \
         [lindex ${drp_talk} [rand [llength ${drp_talk}]]]\001]

    # -- occasionally add a "help" line before the draw...
   if { [rand 6] } { return -code ok }
   set drp_talk {
      "\[type \"!draw 5\" to discard your 5th card\]"
      "\[type \"!keep 1234\" to discard your 5th card\]"
      "\[to draw new 1st and 4th cards type \"!draw 14\"\]"
      "\[type \"!draw 3\" to draw a new 3rd card\]"
      "\[type \"!keep 345\" to discard the 1st and 2nd cards\]"
      "\[to discard the 2nd and 3rd card type \"!draw 23\"\]"
      "\[type \"!draw 2\" to draw a new 2nd card\]"
      "\[type \"!keep 45\" to hang on to the 4th and 5th cards\]"
      "\[use \"!draw\" or \"!keep\" to hold all of your cards\]"
      "\[to hold on to the 2nd and 5th cards type \"!keep 25\"\]"
   }
   putserv [concat PRIVMSG "${drp_chan}" :\001ACTION * \
         [lindex ${drp_talk} [rand [llength ${drp_talk}]]]\001]

   return -code ok
}
 #
 # --------------------------------

 # --------------------------------
 #  DrP.Draw
 #    This creates the final hand using args from the !draw command.
 #
proc DrP.Draw { drp_nick v1 v2 drp_chan drp_text } {
   global drp_Running drp_Drawing drp_Players

    # -- bail out if the bot triggered this proc...
   if { [isbotnick "${drp_nick}"] } { return -code ok }

    # -- bail out if not playing on this channel...
   if { ![info exists drp_Running(${drp_chan})] } { return -code ok }

    # -- bail out if not currently !draw'ing on this channel...
   if { ![info exists drp_Drawing(${drp_chan})] } { return -code ok }

    # -- make the player's new hand...
   set drp_count -1
   foreach drp_hand $drp_Players(${drp_chan}) {
      incr drp_count
       # -- continue if nick isn't player from list...
      if { ![string equal "${drp_nick}" [lindex ${drp_hand} 0]] } {
         continue
      }
       # -- check length of hand to see if its been drawn already...
      if { [llength ${drp_hand}] < 10 } break

       # -- keep the first 4 draw numbers (of 5 or less)...
      regsub -all \[^0-5\] "${drp_text}" "" drp_draws
      if { [string equal "" "${drp_draws}"] } { set drp_draws 0 }
      set drp_draws [lrange \
            [lsort -decreasing -unique [split ${drp_draws} ""]] 0 3]

       # -- check for drawing 4 cards to an Ace...
      set drp_keeps ""
      foreach drp_arg { 1 2 3 4 5 } {
         set drp_cntr 0
         foreach drp_arg2 ${drp_draws} {
            incr drp_cntr [string equal "${drp_arg}" "${drp_arg2}"]
         }
         if { ! ${drp_cntr} } { lappend drp_keeps ${drp_arg} }
      }
      if { [llength ${drp_keeps}] == 1 } {
         switch -- [string index [lindex \
               [lindex ${drp_hand} ${drp_keeps}] 1] 0] {
            "A" { set drp_replace "" }
            "-" { set drp_replace "\00303,00 A of ? \003" }
            "=" { set drp_replace "\00306,00 A of ? \003" }
            default  {
               set drp_replace ""
               set drp_draws [lrange ${drp_draws} 1 end]
            }
         }
         if { ![string equal "" "${drp_replace}"] } {
            set drp_hand [lreplace ${drp_hand} \
                  ${drp_keeps} ${drp_keeps} ${drp_replace}]
            set drp_Players(${drp_chan}) \
                  [lreplace $drp_Players(${drp_chan}) \
                  ${drp_count} ${drp_count} ${drp_hand}]
         }
      }

       # -- if no cards are drawn, shorten the list from the right
       #    end otherwise replace list elements for each arg...
      foreach drp_drarg ${drp_draws} {
         if { [lindex ${drp_draws} end] == 0 } {
            set drp_hand [lrange ${drp_hand} 0 5]
            break
         }
         set drp_hand [lreplace [lreplace ${drp_hand} ${drp_drarg} \
               ${drp_drarg} [lindex ${drp_hand} end]] end end]
      }

       # -- make final hand...
      set drp_Players(${drp_chan}) \
            [lreplace $drp_Players(${drp_chan}) \
            ${drp_count} ${drp_count} [lrange ${drp_hand} 0 5]]
   }

    # -- move along to DrP.Show if all players have drawn...
   set drp_drawed 0
   foreach drp_player $drp_Players(${drp_chan}) {
      incr drp_drawed [expr [llength ${drp_player}] > 6]
   }
   if { ! ${drp_drawed} } { after 1000 [list DrP.Show "${drp_chan}"] }

   return -code ok
}
 #
 # --------------------------------

 # --------------------------------
 #  DrP.Keep
 #    This catches !keep commands and sends them to DrP.Draw.
 #
proc DrP.Keep { drp_nick v1 v2 drp_chan drp_text } {
   global drp_Running drp_Drawing

    # -- bail out if the bot triggered this proc...
   if { [isbotnick "${drp_nick}"] } { return -code ok }

    # -- bail out if not playing on this channel...
   if { ![info exists drp_Running(${drp_chan})] } { return -code ok }

    # -- bail out if not currently !draw'ing on this channel...
   if { ![info exists drp_Drawing(${drp_chan})] } { return -code ok }

    # -- keep the first 4 numbers (of 5 or less)...
   regsub -all \[^0-5\] "${drp_text}" "" drp_keeps
   if { [string equal "" "${drp_keeps}"] } { set drp_keeps 0 }
   set drp_keeps [lrange \
         [lsort -decreasing -unique [split ${drp_keeps} ""]] 0 3]

    # -- make the draw list from what is not in the keep list...
   set drp_draws ""
   foreach drp_arg { 1 2 3 4 5 } {
      set drp_cntr 0
      foreach drp_arg2 ${drp_keeps} {
         incr drp_cntr [string equal "${drp_arg}" "${drp_arg2}"]
      }
      if { ! ${drp_cntr} } { lappend drp_draws ${drp_arg} }
   }
   if { [llength ${drp_draws}] == 5 } { set drp_draws 0 }

    # -- call the draw proc with proper args...
   DrP.Draw "${drp_nick}" v1 v2 "${drp_chan}" "${drp_draws}"

   return -code ok
}
 #
 # --------------------------------

 # --------------------------------
 #  DrP.Show
 #    This shows the final hands to the remaining players.
 #
proc DrP.Show { drp_chan } {
   global drp_Running drp_Drawing drp_Players

    # -- cancel any upcoming "afters"...
   after cancel [list DrP.Show "${drp_chan}"]

    # -- bail out if not playing on this channel...
   if { ![info exists drp_Running(${drp_chan})] } { return -code ok }

    # -- end drawing... (was set in DrP.Play to let them !draw)...
   if { [info exists drp_Drawing(${drp_chan})] } {
      unset drp_Drawing(${drp_chan})
   }

    # -- bail out if nobody is in...
   if { ![llength $drp_Players(${drp_chan})] } {
      DrP.NoPlayers "${drp_chan}"
      return -code ok
   }

    # -- select a phrase and say it to the channel...
   set drp_talk {
      "no more draws.. here are the final hands.."
      "who will win this hand?.. cards coming.."
      "who wins this one?.. here are the cards.."
      "here is the final showdown.."
      "and now the moment you've been waiting for.."
      "and now to show the final hands.."
      "okay everyone.. read 'em and weep.."
      "done drawing.. here are the hands you're stuck with.."
      "time to refresh the hands.. ready players?"
      "if you didn't draw yet too late now.. the hands are.."
   }
   putserv [concat PRIVMSG "${drp_chan}" :\001ACTION * \
         [lindex ${drp_talk} [rand [llength ${drp_talk}]]]\001]

    # -- deal out the final hands...
   foreach drp_hand $drp_Players(${drp_chan}) {
      putserv [concat PRIVMSG \
            "${drp_chan}" :\001ACTION \00301,15[format " % 9s " \
            [lindex ${drp_hand} 0]]\003[join [lrange \
            ${drp_hand} 1 5] "\00301,15 \003"]\00301,15 \003\001]
   }

    # -- select a phrase and say it to the channel...
   set drp_talk {
      "that's how it all ends up!"
      "the winner takes the chips!"
      "another good game of poker!"
      "game over.. everybody wins!"
      "and that is the end of that!"
      "time to pay up all bets people!"
      "good game boys and girls!"
      "good game ladies and gentlemen!"
      "thanks for playing!"
      "great fun.. good game!"
   }
   lappend drp_talk "thanks for playing Dr. Po Poker!"
   putserv [concat PRIVMSG "${drp_chan}" :\001ACTION * \
         [lindex ${drp_talk} [rand [llength ${drp_talk}]]]\001]

    # -- every so often remind the ops that they can turn game off...
   if { ![rand 20] } {
      set drp_talk \
            "\[an OP may type \"!poker off\" to deactivate !poker\]"
      putserv [concat \
            PRIVMSG "${drp_chan}" :\001ACTION * ${drp_talk}\001]
   }

    # -- clean up the vars and timers...
   DrP.Finish "${drp_chan}"

   return -code ok
}
 #
 # --------------------------------

 # --------------------------------
 #  DrP.Fold
 #    This removes a player from the list with the !fold command.
 #
proc DrP.Fold { drp_nick v1 v2 drp_chan v4 } {
   global drp_Running drp_Players

    # -- bail out if the bot triggered this proc...
   if { [isbotnick "${drp_nick}"] } { return -code ok }

    # -- bail out if not playing on this channel...
   if { ![info exists drp_Running(${drp_chan})] } { return -code ok }

    # -- remove player's name from players list...
   set drp_found 0
   set drp_count 0
   foreach drp_player $drp_Players(${drp_chan}) {
      if { [string equal "${drp_nick}" [lindex ${drp_player} 0]] } {
         set drp_Players(${drp_chan}) [lreplace \
               $drp_Players(${drp_chan}) ${drp_count} ${drp_count}]
         incr drp_found
         break
      }
      incr drp_count
   }

    # -- if nick wasn't playing just bail out here...
   if { ! ${drp_found} } { return -code ok }

    # -- make a comment on occasion...
   if { ![rand 6] } {
      set drp_talk {
         "uh oh NICK.. bummer"
         "i guess NICK couldn't take it"
         "i see it got too hot for NICK"
         "we watch as NICK folds"
         "the heat is on NICK"
         "okay seeya NICK"
         "i figured NICK might do that"
         "okay bye NICK"
         "folding NICK?.. okay"
         "know when to hold 'em.. know when to fold 'em NICK!"
      }
      regsub NICK [lindex ${drp_talk} \
            [rand [llength ${drp_talk}]]] "${drp_nick}" drp_talk
      putserv [concat \
            PRIVMSG "${drp_chan}" :\001ACTION * ${drp_talk}\001]
   }

    # -- if this was the last player go to DrP.NoPlayers..
   if { [isbotnick [lindex \
         [lindex $drp_Players(${drp_chan}) 0] 0]] ||
         ![llength $drp_Players(${drp_chan})] } {
      DrP.NoPlayers "${drp_chan}"
      return -code ok
   }

   return -code ok
}
 #
 # --------------------------------

 # --------------------------------
 #  DrP.Finish
 #    This is called from various procs to close this session.
 #
proc DrP.Finish { drp_chan } {
   global drp_Running drp_Dealing drp_Drawing drp_Players

    # -- unset all global array vars and cancel "afters"...
   foreach drp_global [info vars "drp_\[A-Z\]*"] {
      if { [info exists ${drp_global}(${drp_chan})] } {
         unset ${drp_global}(${drp_chan})
      }
      after cancel [list unset ${drp_global}(${drp_chan})]
   }
   foreach drp_proc [info procs DrP.*] {
      after cancel [list ${drp_proc} "${drp_chan}"]
   }

   return -code ok
}
 #
 # --------------------------------

 # --------------------------------
 #  DrP.NoPlayers
 #    This closes out the game in cases where there are no players.
 #
proc DrP.NoPlayers { drp_chan } {
   global drp_Running drp_Players

    # -- bail out if not playing on this channel...
   if { ![info exists drp_Running(${drp_chan})] } { return -code ok }

    # -- select a comment and say it...
   set drp_talk {
      "hmmm.. that's all?.. okay i'm done if you are"
      "i've looked around.. no more players.. i'm done"
      "fine.. no poker players.. i'll play solitaire"
      "game over.. everybody quit.. try again later"
      "okay i'm done dealing.. nobody here to play with"
      "fine.. just quit.. i'll take my cards and go home"
      "nobody playing?.. okay then nobody wins!"
      "the table is empty.. poker game is closed"
      "where'd everybody go?.. was it something i said?"
      "if nobody plays i'll just.. ummm.. play with myself!"
   }
   putserv [concat PRIVMSG "${drp_chan}" :\001ACTION * \
         [lindex ${drp_talk} [rand [llength ${drp_talk}]]]\001]

   DrP.Finish "${drp_chan}"

   return -code ok
}
 #
 # --------------------------------

 # --------------------------------
 #  DrP.Help
 #    This sends a few short lines of help on the various commands.
 #
proc DrP.Help { drp_chan drp_text } {
   global drp_OppedOff

    # -- bail out if Opped Off...
   if { [info exists drp_OppedOff(${drp_chan})] } {
      if { ![rand 8] } {
         set drp_talk "\[poker is \"off\"..\
               an OP must type \"!poker on\" to restart\]"
         putserv [concat \
               PRIVMSG "${drp_chan}" :\001ACTION * ${drp_talk}\001]
      }
      return -code ok
   }

    # -- test arg against help options...
   switch ${drp_text} {
      "deal" { set drp_help {
         "when the bot offers to play poker type \"!deal\".."
         "the first 5 players to enter the command get in the game"
      } }
      "draw" { set drp_help {
         "to draw new cards type \"!draw <numbers 1-5>\".."
         "the numbers are the positions of cards to discard.."
         "to draw a new 1st and 4th card type:   !draw 14"
      } }
      "keep" { set drp_help {
         "opposite of \"!draw\".. use \"!keep <1-5>\" to hold cards.."
         "to hold the 3rd and 4th cards you enter:   !keep 34"
      } }
      "fold" { set drp_help {
         "type \"!fold\" at any time to withdraw from the game"
      } }
      default { set drp_help {
         "type !poker to start.. if game is \"off\" a channel OP"
         "must type the command \"!poker on\" to re-activate it.."
         "for other help type \"!poker help <command>\".."
         "the four poker commands are:  !deal  !draw  !keep  !fold"
      } }
   }

    # -- send help line to channel...
   foreach drp_talk ${drp_help} {
      putserv [concat \
            PRIVMSG "${drp_chan}" :\001ACTION * ${drp_talk}\001]
   }

   return -code ok
}
 #
 # --------------------------------

putlog [concat Script loaded: \002Dr. Po Poker ${drp_Version}\002]

return -code ok
